Libvirt API for virtualization
==============================

Libvirt provides a portable, long term stable C API for managing the
virtualization technologies provided by many operating systems. It
includes support for QEMU, KVM, Xen, LXC, bhyve, Virtuozzo, VMware
vCenter and ESX, VMware Desktop, Hyper-V, VirtualBox and the POWER
Hypervisor.

For some of these hypervisors, it provides a stateful management
daemon which runs on the virtualization host allowing access to the
API both by non-privileged local users and remote users.

Layered packages provide bindings of the libvirt C API into other
languages including Python, Perl, PHP, Go, Java, OCaml, as well as
mappings into object systems such as GObject, CIM and SNMP.

Further information about the libvirt project can be found on the
website:

[https://libvirt.org](https://libvirt.org)


License
-------

The libvirt C API is distributed under the terms of GNU Lesser General
Public License, version 2.1 (or later). Some parts of the code that are
not part of the C library may have the more restrictive GNU General
Public License, version 2.0 (or later). See the files
[COPYING.LESSER](COPYING.LESSER) and [COPYING](COPYING)
for full license terms & conditions.


Installing dependencies
-----------------------

```bash
yum install autoconf automake gettext-devel libtool perl-podlators gcc git \
    perl python systemd libxml2-devel libxslt readline-devel bash-completion \
    ncurses-devel gettext libtasn1-devel gnutls-devel libattr-devel \
    libblkid-devel augeas systemd-devel libpciaccess-devel yajl-devel \
    libpcap-devel libnl3-devel libselinux-devel dnsmasq iptables radvd \
    ebtables kmod cyrus-sasl-devel polkit patch util-linux libacl-devel \
    qemu-img-vz lvm2 iscsi-initiator-utils parted-devel device-mapper-devel \
    xfsprogs-devel numactl-devel libcap-ng-devel netcf-devel audit-libs-devel \
    systemtap-sdt-devel nfs-utils dbus-devel gawk scrub numad libprlsdk-devel \
    ploop-devel libvzctl-devel libvcmmd-devel libvzevent-devel \
    vzkernel-headers perl-XML-XPath libcurl-devel libvcmmd-devel \
    libvzctl-devel libvzctl libwsman-devel glusterfs-api-devel gluster-fs-devel \
    librbd1-devel librados2-devel
```


Building & Installing
---------------------

First configure the build and enable necessary drivers. If you ever need to
reconfigure the build, there is no need to run `autogen.sh` script again.

```bash
NOCONFIGURE=1 ./autogen.sh --system
./configure --build=x86_64-virtuozzo-linux-gnu \
    --host=x86_64-virtuozzo-linux-gnu --program-prefix= \
    --disable-dependency-tracking --prefix=/usr --exec-prefix=/usr \
    --bindir=/usr/bin --sbindir=/usr/sbin --sysconfdir=/etc \
    --datadir=/usr/share --includedir=/usr/include --libdir=/usr/lib64 \
    --libexecdir=/usr/libexec --localstatedir=/var --sharedstatedir=/var/lib \
    --mandir=/usr/share/man --infodir=/usr/share/info --with-qemu \
    --without-openvz --with-lxc --without-vbox --without-libxl --with-sasl \
    --with-polkit --with-libvirtd --without-phyp --with-esx \
    --without-hyperv --without-vmware --without-xenapi --with-vz --with-vzct \
    --with-docker --without-bhyve --with-interface --with-network \
    --with-storage-fs --with-storage-lvm --with-storage-iscsi \
    --with-storage-scsi --with-storage-disk --with-storage-mpath \
    --without-storage-iscsi-direct --without-storage-rbd \
    --without-storage-sheepdog --with-storage-gluster --without-storage-zfs \
    --without-storage-vstorage --with-numactl --with-numad --with-capng \
    --without-fuse --with-netcf --with-selinux \
    --with-selinux-mount=/sys/fs/selinux --without-apparmor --without-hal \
    --with-udev --with-yajl --without-sanlock --with-libpcap --with-macvtap \
    --with-audit --with-dtrace --with-driver-modules --with-firewalld \
    --without-firewalld-zone --without-wireshark-dissector --without-pm-utils \
    --with-nss-plugin --with-qemu-user=root --with-qemu-group=qemu \
    --with-tls-priority=NORMAL --without-secrets --enable-werror \
    --enable-expensive-tests --with-init-script=systemd --without-login-shell
```

Then build and install

```bash
make
make install
```
